<?php
/**
 * @version		$Id: common.php 20196 2011-01-26 12:42:15Z donpool $
 * @package		JeTs.Framework
 * @subpackage	common
 * @copyright	Copyright (C) 2006 - 2011 NawesCorp. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

/**
 * Stops Application after dumping $data to browser
 *
 * @param mixed $data to be dumped to browser
 */
function stop( $data = '') {
	$data = print_r( $data, true );
	global $app;
	echo "<b>JeTs debug:</b><pre>$data</pre>";
	$app->close();
	/*
	Alternative:
	echo $data;
	jexit();
	*/
}

/**
 * Shuts down application after showing the $msg message
 *
 * @param string $msg to show
 * @param array $headers of response if any
 */
function shutDown( $msg, array $headers = array() ) {
	global $app;
	foreach ( $headers as $header ) {
		header( $header );
	}
	echo $msg;
	$app->close();
}

/**
 * Gets a 'yyyy-mm-dd' string and converts into 'dd month yyyy' format
 *
 * @param string $date
 * @return string formated date
 */
function formatDate( $date ) {
	$fecha = explode( '-', $date );
	return ucwords( strftime( '%d %b %Y', mktime( 0, 0, 0, $fecha[1], $fecha[2], $fecha[0] ) ) );
}

/**
 * Gets a 'dd month yyyy' string and converts into 'yyyy-mm-dd' format
 *
 * @param string $formated date
 * @return string unformated date
 */
function unFormatDate( $formated ) {
	$date = strptime( $formated, '%d %b %Y' );

	$day = $date['tm_mday'];
	$month = $date['tm_mon'] + 1;
	$year = 1900+$date['tm_year'];

	return strftime( '%Y-%m-%d', mktime( 0,0,0,$month,$day,$year ) );
}


/** INI: From http://www.php.net/manual/en/function.preg-replace.php **/
/**
 * Removes accents from a string
 *
 * @param string $str contaning accents
 * @return string without accents
 */
function remove_accent( $str ) {
  $a = array('À', 'Á', 'Â', 'Ã', 'Ä', 'Å', 'Æ', 'Ç', 'È', 'É', 'Ê', 'Ë', 'Ì', 'Í', 'Î', 'Ï', 'Ð', 'Ñ', 'Ò', 'Ó', 'Ô', 'Õ', 'Ö', 'Ø', 'Ù', 'Ú', 'Û', 'Ü', 'Ý', 'ß', 'à', 'á', 'â', 'ã', 'ä', 'å', 'æ', 'ç', 'è', 'é', 'ê', 'ë', 'ì', 'í', 'î', 'ï', 'ñ', 'ò', 'ó', 'ô', 'õ', 'ö', 'ø', 'ù', 'ú', 'û', 'ü', 'ý', 'ÿ', 'Ā', 'ā', 'Ă', 'ă', 'Ą', 'ą', 'Ć', 'ć', 'Ĉ', 'ĉ', 'Ċ', 'ċ', 'Č', 'č', 'Ď', 'ď', 'Đ', 'đ', 'Ē', 'ē', 'Ĕ', 'ĕ', 'Ė', 'ė', 'Ę', 'ę', 'Ě', 'ě', 'Ĝ', 'ĝ', 'Ğ', 'ğ', 'Ġ', 'ġ', 'Ģ', 'ģ', 'Ĥ', 'ĥ', 'Ħ', 'ħ', 'Ĩ', 'ĩ', 'Ī', 'ī', 'Ĭ', 'ĭ', 'Į', 'į', 'İ', 'ı', 'Ĳ', 'ĳ', 'Ĵ', 'ĵ', 'Ķ', 'ķ', 'Ĺ', 'ĺ', 'Ļ', 'ļ', 'Ľ', 'ľ', 'Ŀ', 'ŀ', 'Ł', 'ł', 'Ń', 'ń', 'Ņ', 'ņ', 'Ň', 'ň', 'ŉ', 'Ō', 'ō', 'Ŏ', 'ŏ', 'Ő', 'ő', 'Œ', 'œ', 'Ŕ', 'ŕ', 'Ŗ', 'ŗ', 'Ř', 'ř', 'Ś', 'ś', 'Ŝ', 'ŝ', 'Ş', 'ş', 'Š', 'š', 'Ţ', 'ţ', 'Ť', 'ť', 'Ŧ', 'ŧ', 'Ũ', 'ũ', 'Ū', 'ū', 'Ŭ', 'ŭ', 'Ů', 'ů', 'Ű', 'ű', 'Ų', 'ų', 'Ŵ', 'ŵ', 'Ŷ', 'ŷ', 'Ÿ', 'Ź', 'ź', 'Ż', 'ż', 'Ž', 'ž', 'ſ', 'ƒ', 'Ơ', 'ơ', 'Ư', 'ư', 'Ǎ', 'ǎ', 'Ǐ', 'ǐ', 'Ǒ', 'ǒ', 'Ǔ', 'ǔ', 'Ǖ', 'ǖ', 'Ǘ', 'ǘ', 'Ǚ', 'ǚ', 'Ǜ', 'ǜ', 'Ǻ', 'ǻ', 'Ǽ', 'ǽ', 'Ǿ', 'ǿ');
  $b = array('A', 'A', 'A', 'A', 'A', 'A', 'AE', 'C', 'E', 'E', 'E', 'E', 'I', 'I', 'I', 'I', 'D', 'N', 'O', 'O', 'O', 'O', 'O', 'O', 'U', 'U', 'U', 'U', 'Y', 's', 'a', 'a', 'a', 'a', 'a', 'a', 'ae', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i', 'n', 'o', 'o', 'o', 'o', 'o', 'o', 'u', 'u', 'u', 'u', 'y', 'y', 'A', 'a', 'A', 'a', 'A', 'a', 'C', 'c', 'C', 'c', 'C', 'c', 'C', 'c', 'D', 'd', 'D', 'd', 'E', 'e', 'E', 'e', 'E', 'e', 'E', 'e', 'E', 'e', 'G', 'g', 'G', 'g', 'G', 'g', 'G', 'g', 'H', 'h', 'H', 'h', 'I', 'i', 'I', 'i', 'I', 'i', 'I', 'i', 'I', 'i', 'IJ', 'ij', 'J', 'j', 'K', 'k', 'L', 'l', 'L', 'l', 'L', 'l', 'L', 'l', 'l', 'l', 'N', 'n', 'N', 'n', 'N', 'n', 'n', 'O', 'o', 'O', 'o', 'O', 'o', 'OE', 'oe', 'R', 'r', 'R', 'r', 'R', 'r', 'S', 's', 'S', 's', 'S', 's', 'S', 's', 'T', 't', 'T', 't', 'T', 't', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'W', 'w', 'Y', 'y', 'Y', 'Z', 'z', 'Z', 'z', 'Z', 'z', 's', 'f', 'O', 'o', 'U', 'u', 'A', 'a', 'I', 'i', 'O', 'o', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'U', 'u', 'A', 'a', 'AE', 'ae', 'O', 'o');
  return str_replace( $a, $b, $str );
}

/**
 * For creating clean urls from titles
 * Example: post_slug(' -Lo#&@rem  IPSUM //dolor-/sit - amet-/-consectetur! 12 -- ') 
 * will output: lorem-ipsum-dolor-sit-amet-consectetur-12
 *
 * @param string $str to be slugged
 * @return string containing slugged phrase
 */
function post_slug( $str ) {
  return strtolower( preg_replace( array( '/[^a-zA-Z0-9 -]/', '/[ -]+/', '/^-|-$/' ), array( '', '-', '' ), remove_accent( $str ) ) );
}
/** END: From http://www.php.net/manual/en/function.preg-replace.php **/
